# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: blueprint.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0f\x62lueprint.proto\x12\x13\x63onnector.blueprint\x1a\x1bgoogle/protobuf/empty.proto\x1a\x19google/protobuf/any.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"c\n\x13\x42lueprintGetRequest\x12\x16\n\x0e\x62lueprint_uuid\x18\x01 \x01(\t\x12\x34\n\x04type\x18\x02 \x01(\x0e\x32&.connector.blueprint.BlueprintTypeEnum\"\xfd\x03\n\x11\x42lueprintResponse\x12:\n\toperation\x18\x01 \x01(\x0e\x32\".connector.blueprint.OperationEnumH\x00\x88\x01\x01\x12\x14\n\x07success\x18\x02 \x01(\x08H\x01\x88\x01\x01\x12\x11\n\x04uuid\x18\x03 \x01(\tH\x02\x88\x01\x01\x12\x10\n\x03key\x18\x04 \x01(\tH\x03\x88\x01\x01\x12\x11\n\x04name\x18\x05 \x01(\tH\x04\x88\x01\x01\x12\x39\n\x04type\x18\x06 \x01(\x0e\x32&.connector.blueprint.BlueprintTypeEnumH\x05\x88\x01\x01\x12\x11\n\x04icon\x18\x07 \x01(\tH\x06\x88\x01\x01\x12\x30\n\rconfiguration\x18\x08 \x01(\x0b\x32\x14.google.protobuf.AnyH\x07\x88\x01\x01\x12\x33\n\ncreated_at\x18\t \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x08\x88\x01\x01\x12\x33\n\nupdated_at\x18\n \x01(\x0b\x32\x1a.google.protobuf.TimestampH\t\x88\x01\x01\x42\x0c\n\n_operationB\n\n\x08_successB\x07\n\x05_uuidB\x06\n\x04_keyB\x07\n\x05_nameB\x07\n\x05_typeB\x07\n\x05_iconB\x10\n\x0e_configurationB\r\n\x0b_created_atB\r\n\x0b_updated_at\"\x98\x01\n\x12\x42lueprintsResponse\x12\x35\n\toperation\x18\x01 \x01(\x0e\x32\".connector.blueprint.OperationEnum\x12\x0f\n\x07success\x18\x02 \x01(\x08\x12:\n\nblueprints\x18\x03 \x03(\x0b\x32&.connector.blueprint.BlueprintResponse*X\n\x11\x42lueprintTypeEnum\x12\x11\n\rATS_BLUEPRINT\x10\x00\x12\x15\n\x11\x43HANNEL_BLUEPRINT\x10\x01\x12\x19\n\x15INTEGRATION_BLUEPRINT\x10\x02*F\n\rOperationEnum\x12\x07\n\x03GET\x10\x00\x12\n\n\x06\x43REATE\x10\x01\x12\x08\n\x04READ\x10\x02\x12\n\n\x06UPDATE\x10\x03\x12\n\n\x06\x44\x45LETE\x10\x04\x32\xb4\x01\n\x10\x42lueprintService\x12W\n\x03Get\x12(.connector.blueprint.BlueprintGetRequest\x1a&.connector.blueprint.BlueprintResponse\x12G\n\x04Read\x12\x16.google.protobuf.Empty\x1a\'.connector.blueprint.BlueprintsResponseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'blueprint_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_BLUEPRINTTYPEENUM']._serialized_start=897
  _globals['_BLUEPRINTTYPEENUM']._serialized_end=985
  _globals['_OPERATIONENUM']._serialized_start=987
  _globals['_OPERATIONENUM']._serialized_end=1057
  _globals['_BLUEPRINTGETREQUEST']._serialized_start=129
  _globals['_BLUEPRINTGETREQUEST']._serialized_end=228
  _globals['_BLUEPRINTRESPONSE']._serialized_start=231
  _globals['_BLUEPRINTRESPONSE']._serialized_end=740
  _globals['_BLUEPRINTSRESPONSE']._serialized_start=743
  _globals['_BLUEPRINTSRESPONSE']._serialized_end=895
  _globals['_BLUEPRINTSERVICE']._serialized_start=1060
  _globals['_BLUEPRINTSERVICE']._serialized_end=1240
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: chart_dispatcher.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x16\x63hart_dispatcher.proto\x12\x1a\x63onnector.chart_dispatcher\x1a\x19google/protobuf/any.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"/\n\x19\x43hartDispatcherGetRequest\x12\x12\n\nchart_uuid\x18\x01 \x01(\t\"\\\n\x1c\x43hartDispatcherCreateRequest\x12\x12\n\nchart_uuid\x18\x01 \x01(\t\x12(\n\ndispatcher\x18\x02 \x01(\x0b\x32\x14.google.protobuf.Any\"\\\n\x1c\x43hartDispatcherUpdateRequest\x12\x12\n\nchart_uuid\x18\x01 \x01(\t\x12(\n\ndispatcher\x18\x02 \x01(\x0b\x32\x14.google.protobuf.Any\"2\n\x1c\x43hartDispatcherDeleteRequest\x12\x12\n\nchart_uuid\x18\x01 \x01(\t\"\xd6\x02\n\x17\x43hartDispatcherResponse\x12<\n\toperation\x18\x01 \x01(\x0e\x32).connector.chart_dispatcher.OperationEnum\x12\x0f\n\x07success\x18\x02 \x01(\x08\x12\x17\n\nchart_uuid\x18\x03 \x01(\tH\x00\x88\x01\x01\x12-\n\ndispatcher\x18\x04 \x01(\x0b\x32\x14.google.protobuf.AnyH\x01\x88\x01\x01\x12\x33\n\ncreated_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x02\x88\x01\x01\x12\x33\n\nupdated_at\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x03\x88\x01\x01\x42\r\n\x0b_chart_uuidB\r\n\x0b_dispatcherB\r\n\x0b_created_atB\r\n\x0b_updated_at*F\n\rOperationEnum\x12\x07\n\x03GET\x10\x00\x12\n\n\x06\x43REATE\x10\x01\x12\x08\n\x04READ\x10\x02\x12\n\n\x06UPDATE\x10\x03\x12\n\n\x06\x44\x45LETE\x10\x04\x32\xf6\x03\n\x16\x43hartDispatcherService\x12q\n\x03Get\x12\x35.connector.chart_dispatcher.ChartDispatcherGetRequest\x1a\x33.connector.chart_dispatcher.ChartDispatcherResponse\x12w\n\x06\x43reate\x12\x38.connector.chart_dispatcher.ChartDispatcherCreateRequest\x1a\x33.connector.chart_dispatcher.ChartDispatcherResponse\x12w\n\x06Update\x12\x38.connector.chart_dispatcher.ChartDispatcherUpdateRequest\x1a\x33.connector.chart_dispatcher.ChartDispatcherResponse\x12w\n\x06\x44\x65lete\x12\x38.connector.chart_dispatcher.ChartDispatcherDeleteRequest\x1a\x33.connector.chart_dispatcher.ChartDispatcherResponseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'chart_dispatcher_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_OPERATIONENUM']._serialized_start=748
  _globals['_OPERATIONENUM']._serialized_end=818
  _globals['_CHARTDISPATCHERGETREQUEST']._serialized_start=114
  _globals['_CHARTDISPATCHERGETREQUEST']._serialized_end=161
  _globals['_CHARTDISPATCHERCREATEREQUEST']._serialized_start=163
  _globals['_CHARTDISPATCHERCREATEREQUEST']._serialized_end=255
  _globals['_CHARTDISPATCHERUPDATEREQUEST']._serialized_start=257
  _globals['_CHARTDISPATCHERUPDATEREQUEST']._serialized_end=349
  _globals['_CHARTDISPATCHERDELETEREQUEST']._serialized_start=351
  _globals['_CHARTDISPATCHERDELETEREQUEST']._serialized_end=401
  _globals['_CHARTDISPATCHERRESPONSE']._serialized_start=404
  _globals['_CHARTDISPATCHERRESPONSE']._serialized_end=746
  _globals['_CHARTDISPATCHERSERVICE']._serialized_start=821
  _globals['_CHARTDISPATCHERSERVICE']._serialized_end=1323
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: platform.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0eplatform.proto\x12\x12\x63onnector.platform\x1a\x19google/protobuf/any.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\x9b\x03\n\x10PlatformResponse\x12\x39\n\toperation\x18\x01 \x01(\x0e\x32!.connector.platform.OperationEnumH\x00\x88\x01\x01\x12\x14\n\x07success\x18\x02 \x01(\x08H\x01\x88\x01\x01\x12\x11\n\x04uuid\x18\x03 \x01(\tH\x02\x88\x01\x01\x12\x10\n\x03key\x18\x04 \x01(\tH\x03\x88\x01\x01\x12\x11\n\x04name\x18\x05 \x01(\tH\x04\x88\x01\x01\x12\x30\n\rconfiguration\x18\x06 \x01(\x0b\x32\x14.google.protobuf.AnyH\x05\x88\x01\x01\x12\x33\n\ncreated_at\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x06\x88\x01\x01\x12\x33\n\nupdated_at\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x07\x88\x01\x01\x42\x0c\n\n_operationB\n\n\x08_successB\x07\n\x05_uuidB\x06\n\x04_keyB\x07\n\x05_nameB\x10\n\x0e_configurationB\r\n\x0b_created_atB\r\n\x0b_updated_at\"\x93\x01\n\x11PlatformsResponse\x12\x34\n\toperation\x18\x01 \x01(\x0e\x32!.connector.platform.OperationEnum\x12\x0f\n\x07success\x18\x02 \x01(\x08\x12\x37\n\tplatforms\x18\x03 \x03(\x0b\x32$.connector.platform.PlatformResponse*F\n\rOperationEnum\x12\x07\n\x03GET\x10\x00\x12\n\n\x06\x43REATE\x10\x01\x12\x08\n\x04READ\x10\x02\x12\n\n\x06UPDATE\x10\x03\x12\n\n\x06\x44\x45LETE\x10\x04\x32X\n\x0fPlatformService\x12\x45\n\x04Read\x12\x16.google.protobuf.Empty\x1a%.connector.platform.PlatformsResponseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'platform_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_OPERATIONENUM']._serialized_start=691
  _globals['_OPERATIONENUM']._serialized_end=761
  _globals['_PLATFORMRESPONSE']._serialized_start=128
  _globals['_PLATFORMRESPONSE']._serialized_end=539
  _globals['_PLATFORMSRESPONSE']._serialized_start=542
  _globals['_PLATFORMSRESPONSE']._serialized_end=689
  _globals['_PLATFORMSERVICE']._serialized_start=763
  _globals['_PLATFORMSERVICE']._serialized_end=851
# @@protoc_insertion_point(module_scope)



from google.protobuf import any_pb2 as _any_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class DispatcherRequest(_message.Message):
    __slots__ = ["chart_uuid"]
    CHART_UUID_FIELD_NUMBER: _ClassVar[int]
    chart_uuid: str
    def __init__(self, chart_uuid: _Optional[str] = ...) -> None: ...

class DispatcherResponse(_message.Message):
    __slots__ = ["success", "cached", "payload"]
    SUCCESS_FIELD_NUMBER: _ClassVar[int]
    CACHED_FIELD_NUMBER: _ClassVar[int]
    PAYLOAD_FIELD_NUMBER: _ClassVar[int]
    success: bool
    cached: bool
    payload: _any_pb2.Any
    def __init__(self, success: bool = ..., cached: bool = ..., payload: _Optional[_Union[_any_pb2.Any, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: metric.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0cmetric.proto\x12\x10\x63onnector.metric\x1a\x19google/protobuf/any.proto\x1a\x1fgoogle/protobuf/timestamp.proto\")\n\x11MetricReadRequest\x12\x14\n\x0c\x63ompany_uuid\x18\x01 \x01(\t\"\'\n\x10MetricGetRequest\x12\x13\n\x0bmetric_uuid\x18\x01 \x01(\t\"\xe7\x01\n\x13MetricCreateRequest\x12\x1b\n\x13\x63onnect_portal_uuid\x18\x01 \x01(\t\x12\x14\n\x0c\x63ompany_uuid\x18\x02 \x01(\t\x12\x0b\n\x03key\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x0e\n\x06\x63ustom\x18\x05 \x01(\t\x12*\n\x04type\x18\x07 \x01(\x0e\x32\x1c.connector.metric.MetricType\x12+\n\rconfiguration\x18\x08 \x01(\x0b\x32\x14.google.protobuf.Any\x12\x19\n\x11\x63onnected_metrics\x18\t \x03(\t\"\x91\x01\n\x13MetricUpdateRequest\x12\x13\n\x0bmetric_uuid\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12*\n\x04type\x18\x03 \x01(\x0e\x32\x1c.connector.metric.MetricType\x12+\n\rconfiguration\x18\x04 \x01(\x0b\x32\x14.google.protobuf.Any\"*\n\x13MetricDeleteRequest\x12\x13\n\x0bmetric_uuid\x18\x01 \x01(\t\"\xb0\x05\n\x0eMetricResponse\x12\x37\n\toperation\x18\x01 \x01(\x0e\x32\x1f.connector.metric.OperationEnumH\x00\x88\x01\x01\x12\x14\n\x07success\x18\x02 \x01(\x08H\x01\x88\x01\x01\x12\x11\n\x04uuid\x18\x03 \x01(\tH\x02\x88\x01\x01\x12\x10\n\x03key\x18\x04 \x01(\tH\x03\x88\x01\x01\x12\x11\n\x04name\x18\x05 \x01(\tH\x04\x88\x01\x01\x12\x13\n\x06\x63ustom\x18\x06 \x01(\x08H\x05\x88\x01\x01\x12/\n\x04type\x18\x07 \x01(\x0e\x32\x1c.connector.metric.MetricTypeH\x06\x88\x01\x01\x12 \n\x13\x63onnect_portal_uuid\x18\x08 \x01(\tH\x07\x88\x01\x01\x12\x19\n\x0c\x63ompany_uuid\x18\t \x01(\tH\x08\x88\x01\x01\x12\x19\n\x11\x63onnected_metrics\x18\n \x03(\t\x12\"\n\x15\x63onnect_portal_method\x18\x0b \x01(\tH\t\x88\x01\x01\x12\x30\n\rconfiguration\x18\x0c \x01(\x0b\x32\x14.google.protobuf.AnyH\n\x88\x01\x01\x12\x33\n\ncreated_at\x18\r \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x0b\x88\x01\x01\x12\x33\n\nupdated_at\x18\x0e \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x0c\x88\x01\x01\x42\x0c\n\n_operationB\n\n\x08_successB\x07\n\x05_uuidB\x06\n\x04_keyB\x07\n\x05_nameB\t\n\x07_customB\x07\n\x05_typeB\x16\n\x14_connect_portal_uuidB\x0f\n\r_company_uuidB\x18\n\x16_connect_portal_methodB\x10\n\x0e_configurationB\r\n\x0b_created_atB\r\n\x0b_updated_at\"\x89\x01\n\x0fMetricsResponse\x12\x32\n\toperation\x18\x01 \x01(\x0e\x32\x1f.connector.metric.OperationEnum\x12\x0f\n\x07success\x18\x02 \x01(\x08\x12\x31\n\x07metrics\x18\x03 \x03(\x0b\x32 .connector.metric.MetricResponse*[\n\nMetricType\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x0b\n\x07INTEGER\x10\x01\x12\x0b\n\x07\x44\x45\x43IMAL\x10\x02\x12\x08\n\x04TEXT\x10\x03\x12\x08\n\x04\x44\x41TE\x10\x04\x12\t\n\x05TRUTH\x10\x05\x12\x07\n\x03URL\x10\x06*P\n\rOperationEnum\x12\x07\n\x03GET\x10\x00\x12\n\n\x06\x43REATE\x10\x01\x12\x08\n\x04READ\x10\x02\x12\n\n\x06UPDATE\x10\x03\x12\n\n\x06\x44\x45LETE\x10\x04\x12\x08\n\x04SYNC\x10\x05\x32\xa5\x03\n\rMetricService\x12N\n\x04Read\x12#.connector.metric.MetricReadRequest\x1a!.connector.metric.MetricsResponse\x12K\n\x03Get\x12\".connector.metric.MetricGetRequest\x1a .connector.metric.MetricResponse\x12Q\n\x06\x43reate\x12%.connector.metric.MetricCreateRequest\x1a .connector.metric.MetricResponse\x12Q\n\x06Update\x12%.connector.metric.MetricUpdateRequest\x1a .connector.metric.MetricResponse\x12Q\n\x06\x44\x65lete\x12%.connector.metric.MetricDeleteRequest\x1a .connector.metric.MetricResponseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'metric_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_METRICTYPE']._serialized_start=1435
  _globals['_METRICTYPE']._serialized_end=1526
  _globals['_OPERATIONENUM']._serialized_start=1528
  _globals['_OPERATIONENUM']._serialized_end=1608
  _globals['_METRICREADREQUEST']._serialized_start=94
  _globals['_METRICREADREQUEST']._serialized_end=135
  _globals['_METRICGETREQUEST']._serialized_start=137
  _globals['_METRICGETREQUEST']._serialized_end=176
  _globals['_METRICCREATEREQUEST']._serialized_start=179
  _globals['_METRICCREATEREQUEST']._serialized_end=410
  _globals['_METRICUPDATEREQUEST']._serialized_start=413
  _globals['_METRICUPDATEREQUEST']._serialized_end=558
  _globals['_METRICDELETEREQUEST']._serialized_start=560
  _globals['_METRICDELETEREQUEST']._serialized_end=602
  _globals['_METRICRESPONSE']._serialized_start=605
  _globals['_METRICRESPONSE']._serialized_end=1293
  _globals['_METRICSRESPONSE']._serialized_start=1296
  _globals['_METRICSRESPONSE']._serialized_end=1433
  _globals['_METRICSERVICE']._serialized_start=1611
  _globals['_METRICSERVICE']._serialized_end=2032
# @@protoc_insertion_point(module_scope)



from google.protobuf import empty_pb2 as _empty_pb2
from google.protobuf import any_pb2 as _any_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class BlueprintTypeEnum(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = []
    ATS_BLUEPRINT: _ClassVar[BlueprintTypeEnum]
    CHANNEL_BLUEPRINT: _ClassVar[BlueprintTypeEnum]
    INTEGRATION_BLUEPRINT: _ClassVar[BlueprintTypeEnum]

class OperationEnum(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = []
    GET: _ClassVar[OperationEnum]
    CREATE: _ClassVar[OperationEnum]
    READ: _ClassVar[OperationEnum]
    UPDATE: _ClassVar[OperationEnum]
    DELETE: _ClassVar[OperationEnum]
ATS_BLUEPRINT: BlueprintTypeEnum
CHANNEL_BLUEPRINT: BlueprintTypeEnum
INTEGRATION_BLUEPRINT: BlueprintTypeEnum
GET: OperationEnum
CREATE: OperationEnum
READ: OperationEnum
UPDATE: OperationEnum
DELETE: OperationEnum

class BlueprintGetRequest(_message.Message):
    __slots__ = ["blueprint_uuid", "type"]
    BLUEPRINT_UUID_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    blueprint_uuid: str
    type: BlueprintTypeEnum
    def __init__(self, blueprint_uuid: _Optional[str] = ..., type: _Optional[_Union[BlueprintTypeEnum, str]] = ...) -> None: ...

class BlueprintResponse(_message.Message):
    __slots__ = ["operation", "success", "uuid", "key", "name", "type", "icon", "configuration", "created_at", "updated_at"]
    OPERATION_FIELD_NUMBER: _ClassVar[int]
    SUCCESS_FIELD_NUMBER: _ClassVar[int]
    UUID_FIELD_NUMBER: _ClassVar[int]
    KEY_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    ICON_FIELD_NUMBER: _ClassVar[int]
    CONFIGURATION_FIELD_NUMBER: _ClassVar[int]
    CREATED_AT_FIELD_NUMBER: _ClassVar[int]
    UPDATED_AT_FIELD_NUMBER: _ClassVar[int]
    operation: OperationEnum
    success: bool
    uuid: str
    key: str
    name: str
    type: BlueprintTypeEnum
    icon: str
    configuration: _any_pb2.Any
    created_at: _timestamp_pb2.Timestamp
    updated_at: _timestamp_pb2.Timestamp
    def __init__(self, operation: _Optional[_Union[OperationEnum, str]] = ..., success: bool = ..., uuid: _Optional[str] = ..., key: _Optional[str] = ..., name: _Optional[str] = ..., type: _Optional[_Union[BlueprintTypeEnum, str]] = ..., icon: _Optional[str] = ..., configuration: _Optional[_Union[_any_pb2.Any, _Mapping]] = ..., created_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., updated_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...

class BlueprintsResponse(_message.Message):
    __slots__ = ["operation", "success", "blueprints"]
    OPERATION_FIELD_NUMBER: _ClassVar[int]
    SUCCESS_FIELD_NUMBER: _ClassVar[int]
    BLUEPRINTS_FIELD_NUMBER: _ClassVar[int]
    operation: OperationEnum
    success: bool
    blueprints: _containers.RepeatedCompositeFieldContainer[BlueprintResponse]
    def __init__(self, operation: _Optional[_Union[OperationEnum, str]] = ..., success: bool = ..., blueprints: _Optional[_Iterable[_Union[BlueprintResponse, _Mapping]]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: connector.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0f\x63onnector.proto\x12\x13\x63onnector.connector\x1a\x19google/protobuf/any.proto\"\'\n\x11\x44ispatcherRequest\x12\x12\n\nchart_uuid\x18\x01 \x01(\t\"\\\n\x12\x44ispatcherResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0e\n\x06\x63\x61\x63hed\x18\x02 \x01(\x08\x12%\n\x07payload\x18\x03 \x01(\x0b\x32\x14.google.protobuf.Any2s\n\x10\x43onnectorService\x12_\n\nDispatcher\x12&.connector.connector.DispatcherRequest\x1a\'.connector.connector.DispatcherResponse0\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'connector_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_DISPATCHERREQUEST']._serialized_start=67
  _globals['_DISPATCHERREQUEST']._serialized_end=106
  _globals['_DISPATCHERRESPONSE']._serialized_start=108
  _globals['_DISPATCHERRESPONSE']._serialized_end=200
  _globals['_CONNECTORSERVICE']._serialized_start=202
  _globals['_CONNECTORSERVICE']._serialized_end=317
# @@protoc_insertion_point(module_scope)



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class JsonMessage(_message.Message):
    __slots__ = ["data"]
    DATA_FIELD_NUMBER: _ClassVar[int]
    data: str
    def __init__(self, data: _Optional[str] = ...) -> None: ...
